@@ -80,8 +80,8 @@ class TerraformWrapper:
             else:
                 exit(1)
         else:
-            if vars(self.args)['cloud'] == None:
-                logger.error("please specify the cloud provider with -cloud argument(-cloud azure/aws/gcloud)")
+            if vars(self.args)['cloud'] is None:
+                logger.error("Please specify a cloud provider with -cloud argument(-cloud azure/aws/gcloud)")
                 raise SystemExit
             cloud_env = vars(self.args)['cloud'].lower()
             if cloud_env == "aws":
@@ -91,9 +91,10 @@ class TerraformWrapper:
             elif cloud_env == "gcloud":
                 gcloud_plugin.configure_remotestate(self.required_vars, self.var_data)
             else:
-                logger.error("incorrect cloud provider entered (e.g. azure, aws, or gcloud)")
+                logger.error("Incorrect cloud provider entered (e.g. azure, aws, or gcloud)")
                 raise SystemExit
 
+
 def entrypoint():
     if not valid_terraform_version(MIN_TERRAFORM_V):
         exit(1)
